@@ -1,7 +1,7 @@
 package Aniki;
 use 5.014002;
 
-use namespace::sweep;
+use namespace::autoclean;
 use Mouse v2.4.5;
 
 use Module::Load ();
@@ -13,7 +13,7 @@ use Aniki::Schema;
 use Aniki::QueryBuilder;
 use Aniki::QueryBuilder::Canonical;
 
-our $VERSION = '1.00';
+our $VERSION = '1.04_01';
 
 use SQL::Maker::SQLType qw/sql_type/;
 use Class::Inspector;
@@ -236,11 +236,13 @@ sub filter_on_insert {
 sub update {
     my $self = shift;
     if (blessed $_[0] && $_[0]->isa('Aniki::Row')) {
-        local $Carp::CarpLevel = $Carp::CarpLevel + 1;
         return $self->update($_[0]->table_name, $_[1], $self->_where_row_cond($_[0]->table, $_[0]->row_data));
     }
     else {
         my ($table_name, $row, $where) = @_;
+        croak '(Aniki#update) `row` is required for update ("SET" parameter)' unless $row && %$row;
+        croak '(Aniki#update) `where` condition must be a reference' unless ref $where;
+
         $row = $self->filter_on_update($table_name, $row);
 
         my $table = $self->schema->get_table($table_name);
@@ -257,11 +259,11 @@ sub update {
 sub delete :method {
     my $self = shift;
     if (blessed $_[0] && $_[0]->isa('Aniki::Row')) {
-        local $Carp::CarpLevel = $Carp::CarpLevel + 1;
         return $self->delete($_[0]->table_name, $self->_where_row_cond($_[0]->table, $_[0]->row_data), @_);
     }
     else {
         my ($table_name, $where, $opt) = @_;
+        croak '(Aniki#delete) `where` condition must be a reference' unless ref $where;
 
         my $table = $self->schema->get_table($table_name);
         if ($table) {
@@ -281,7 +283,6 @@ sub filter_on_update {
 
 sub insert_and_fetch_id {
     my $self = shift;
-    local $Carp::CarpLevel = $Carp::CarpLevel + 1;
 
     local $self->{_context} = $self->dbh;
     $self->insert(@_);
@@ -298,7 +299,6 @@ sub insert_and_fetch_row {
 
     my $table = $self->schema->get_table($table_name) or croak "$table_name is not defined in schema.";
 
-    local $Carp::CarpLevel = $Carp::CarpLevel + 1;
     local $self->{_context} = $self->dbh;
 
     $self->insert($table_name, $row_data, @_);
@@ -316,7 +316,6 @@ sub insert_and_emulate_row {
 
     my $table = $self->schema->get_table($table_name) or croak "$table_name is not defined in schema.";
 
-    local $Carp::CarpLevel = $Carp::CarpLevel + 1;
     local $self->{_context} = $self->dbh;
 
     $row = $self->filter_on_insert($table_name, $row) unless $opt->{no_filter};
@@ -423,8 +422,11 @@ my $WILDCARD_COLUMNS = ['*'];
 
 sub select :method {
     my ($self, $table_name, $where, $opt) = @_;
+    $where //= {};
     $opt //= {};
 
+    croak '(Aniki#select) `where` condition must be a reference.' unless ref $where;
+
     my $table = $self->schema->get_table($table_name);
 
     my $columns = exists $opt->{columns} ? $opt->{columns}
@@ -488,7 +490,7 @@ sub select_by_sql {
     my $prefetch   = exists $opt->{prefetch}    ? $opt->{prefetch}      : [];
        $prefetch   = [$prefetch] if ref $prefetch eq 'HASH';
 
-    my $prefetch_enabled_fg = @$prefetch && !$self->suppress_row_objects;
+    my $prefetch_enabled_fg = @$prefetch && !$self->suppress_row_objects && defined wantarray;
     if ($prefetch_enabled_fg) {
         my $txn; $txn = $self->txn_scope(caller => [caller]) unless $self->in_txn;
 
@@ -499,10 +501,17 @@ sub select_by_sql {
         $txn->rollback if defined $txn; ## for read only
         return $result;
     }
-    else {
-        my $sth = $self->execute($sql, @$bind);
-        return $self->_fetch_by_sth($sth, $table_name, $columns);
+
+    my $sth = $self->execute($sql, @$bind);
+
+    # When the return value is never used, should not create object
+    # case example: use `FOR UPDATE` query for global locking
+    unless (defined wantarray) {
+        $sth->finish();
+        return;
     }
+
+    return $self->_fetch_by_sth($sth, $table_name, $columns);
 }
 
 sub _fetch_by_sth {
@@ -1215,6 +1224,18 @@ Copyright (C) karupanerura.
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 CONTRIBUTORS
+
+=over 2
+
+=item watanabe-yocihi
+
+=item Pine Mizune
+
+=item Syohei YOSHIDA
+
+=back
+
 =head1 AUTHOR
 
 karupanerura E<lt>karupa@cpan.orgE<gt>
