@@ -1,7 +1,7 @@
 package Aniki::Result::Role::Pager;
 use 5.014002;
 
-use namespace::sweep;
+use namespace::autoclean;
 use Mouse::Role;
 use Mouse::Util::TypeConstraints qw/duck_type/;
 
